@@ -310,13 +310,19 @@ class MeasurementRecord:
 
         (they are consumed in order to to minimise peak memory usage)
         """
+
+        def valid_shape(shape):
+            if shape.is_valid:
+                return shape
+            return shape.buffer(0)
+
         geoms = []
         while self.mask_by_grid:
             grid, mask = self.mask_by_grid.popitem()
             mask = mask.astype("uint8")
             shape = shapely.ops.unary_union(
                 [
-                    shapely.geometry.shape(shape)
+                    valid_shape(shapely.geometry.shape(shape))
                     for shape, val in rasterio.features.shapes(mask)
                     if val == 1
                 ]
