@@ -178,15 +178,25 @@ def expected_l1_ls8_folder(
         },
         "crs": "epsg:32655",
         "geometry": {
-            "coordinates": (
-                (
-                    (879_315.0, -3_714_585.0),
-                    (879_315.0, -3_953_115.0),
-                    (641_985.0, -3_953_115.0),
-                    (641_985.0, -3_714_585.0),
-                    (879_315.0, -3_714_585.0),
-                ),
-            ),
+            "coordinates": [
+                [
+                    [879307.5, -3776885.4340469087],
+                    [879307.5, -3778240.713151076],
+                    [839623.3108524992, -3938223.736900397],
+                    [832105.7835592609, -3953107.5],
+                    [831455.8296215904, -3953107.5],
+                    [831453.7930575205, -3953115.0],
+                    [819969.5411349908, -3953115.0],
+                    [641985.0, -3906446.160824098],
+                    [641985.0, -3889797.3351159613],
+                    [685647.6920251067, -3717468.346156044],
+                    [688909.3673333039, -3714585.0],
+                    [708011.4230769231, -3714585.0],
+                    [879315.0, -3761214.3020833335],
+                    [879315.0, -3776857.8139976147],
+                    [879307.5, -3776885.4340469087],
+                ]
+            ],
             "type": "Polygon",
         },
         "grids": {
@@ -335,15 +345,37 @@ def l1_ls7_tarball_md_expected(
             "landsat:wrs_row": 78,
         },
         "geometry": {
-            "coordinates": (
-                (
-                    (770_115.0, -2_768_985.0),
-                    (770_115.0, -2_981_715.0),
-                    (525_285.0, -2_981_715.0),
-                    (525_285.0, -2_768_985.0),
-                    (770_115.0, -2_768_985.0),
-                ),
-            ),
+            "coordinates": [
+                [
+                    [563899.8055973209, -2773901.091688032],
+                    [565174.4110839436, -2768992.5],
+                    [570160.9334151996, -2768992.5],
+                    [570170.5, -2768985.0],
+                    [570223.8384207273, -2768992.5],
+                    [588295.85185022, -2768992.5],
+                    [721491.3496511441, -2790262.4648538055],
+                    [721949.2518894314, -2790326.8512143376],
+                    [758758.6847331291, -2797433.428778118],
+                    [770115.0, -2803848.537800015],
+                    [770115.0, -2819232.438669062],
+                    [745548.1744650088, -2936338.4604302375],
+                    [730486.820264895, -2981715.0],
+                    [707958.3856497289, -2981715.0],
+                    [707665.2711912903, -2981666.327459585],
+                    [695862.7971396025, -2981638.6536404933],
+                    [593801.8189357058, -2963902.554008508],
+                    [537007.2875722996, -2953328.054250119],
+                    [536671.5165534337, -2953272.2984591112],
+                    [526480.1507793682, -2945221.547092697],
+                    [525364.2405528432, -2927837.1702428674],
+                    [529047.5112406499, -2911836.1482165447],
+                    [529451.9856980122, -2906561.9692719015],
+                    [536583.4124976253, -2879098.363725102],
+                    [545784.6687009194, -2839125.873061804],
+                    [562106.6687009194, -2775306.873061804],
+                    [563899.8055973209, -2773901.091688032],
+                ]
+            ],
             "type": "Polygon",
         },
         "grids": {
@@ -475,15 +507,22 @@ def l1_ls5_tarball_md_expected(
             "landsat:wrs_row": 85,
         },
         "geometry": {
-            "coordinates": (
-                (
-                    (835_815.0, -3_881_685.0),
-                    (593_385.0, -3_881_685.0),
-                    (593_385.0, -4_101_015.0),
-                    (835_815.0, -4_101_015.0),
-                    (835_815.0, -3_881_685.0),
-                ),
-            ),
+            "coordinates": [
+                [
+                    [636860.78, -3881685.0],
+                    [593385.0, -4045573.25],
+                    [593385.0, -4062038.8525309917],
+                    [636850.5348070407, -4075317.3559092814],
+                    [768589.1325495897, -4101015.0],
+                    [790215.8408397632, -4101015.0],
+                    [795289.3607718372, -4094590.58897732],
+                    [835815.0, -3937552.555313688],
+                    [835815.0, -3920661.1474690083],
+                    [792349.4651929593, -3907382.6440907186],
+                    [657073.5519714399, -3881685.0],
+                    [636860.78, -3881685.0],
+                ]
+            ],
             "type": "Polygon",
         },
         "grids": {
